#------------------------------------------------------------------------------------------------
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted.
#------------------------------------------------------------------------------------------------
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#------------------------------------------------------------------------------------------------
# IT WAS CREATED AND TESTED IN A WINDOWS ENVIRONMENT ONLY AND MAY NOT FUNCTION ON A MAC.
#------------------------------------------------------------------------------------------------
#    Name:	Select By Material
#      By:	sdmitch
#   Usage:	Select all entities that have the current material applied or hide all entities that
#						do not have the current material applied.
#		 Note:	Materials browser will open if current material is not defined.
#			
#    Date:	Nov 2011
#------------------------------------------------------------------------------------------------

require 'sketchup'

if !file_loaded?(File.basename(__FILE__))
	sub = UI.menu("Plugins").add_submenu("Current Material")
	sub.add_item("Select if  ") { SDM_SBM.select_by_material }
	sub.add_item("Hide if not") { SDM_SBM.hide_by_material }
	file_loaded(File.basename(__FILE__))
end

module SDM_SBM
	
	def self.select_by_material
		mod = Sketchup.active_model
		ent = mod.active_entities
		@sel = mod.selection
		@sel.clear
		if mod.materials.current
			mod.start_operation "select current material"
			recurse1(ent,mod.materials.current)
			mod.commit_operation
		else
			UI.messagebox "Select material to look for and rerun plugin"
			Sketchup.send_action(21074)
			return
		end
	end
	
	def self.recurse1(ents, m)
		ents.each do |e|
			if e.is_a? Sketchup::Group
				unless e.material == nil
					if e.material == m
						@sel.add e
					end
				end
				recurse1(e.entities, m)
			elsif e.is_a? Sketchup::ComponentInstance
				unless e.material == nil
					if e.material == m
						@sel.add e
					end
				end
				recurse1(e.definition.entities, m)
			elsif e.is_a? Sketchup::Face
				unless e.material == nil
					if e.material == m
						@sel.add e
					end
				end
				unless e.back_material == nil
					if e.back_material == m
						@sel.add e
					end
				end
			elsif e.material == m
				@sel.add e
			end
		end
	end
	
	def self.hide_by_material
		mod = Sketchup.active_model
		ent = mod.active_entities
		@sel = mod.selection
		if mod.materials.current
			mod.start_operation "hide non-current material"
			recurse2(ent,mod.materials.current)
			mod.commit_operation
		else
			UI.messagebox "Select material to look for and rerun plugin"
			Sketchup.send_action(21074)
			return
		end
	end
	
	def self.recurse2(ents, m)
		ents.each do |e|
			if e.is_a? Sketchup::Group
				unless e.material == nil
					if e.material != m
						e.hidden=true
					end
				else
					recurse2(e.entities, m)
				end
			elsif e.is_a? Sketchup::ComponentInstance
				unless e.material == nil
					if e.material != m
						e.hidden=true
					end
				else
					recurse2(e.definition.entities, m)
				end
			elsif e.is_a? Sketchup::Face
				if e.material != m && e.back_material != m
					e.hidden=true
				end
			elsif e.material != m
				e.hidden=true
			end
		end
	end
	
end
